module Grammar where

import Text.ParserCombinators.Parsec as Parsec
import Types

identifier = many1 letter <?> "Identifier"

instruction = do
   result <- assignment 
   semicolon
   return result
  <?> "Instruction"

program = many1 instruction

assignment = do
   id <- identifier 
   equal 
   val <- value
   let valInt = (read val)::Int
   return (Assignment id valInt)
 <?> "Assignment"

value = many1 digit

semicolon = do
   commentWsp 
   char ';' 
   commentWsp 
  <?> "Semicolon"

equal = do
   commentWsp 
   char '=' 
   commentWsp 
  <?> "Equal sign"

comment = do
    char '#'
    manyTill anyChar newline
    return ()

-- commentWsp = many (comment <|> spaces)
commentWsp = spaces

parse input = case (Parsec.parse program "" input) of
            Left err -> SyntaxError (show err) 
            Right p  -> Success p


